@@ -1,5 +1,5 @@
 package Net::Stripe::Token;
-$Net::Stripe::Token::VERSION = '0.39';
+$Net::Stripe::Token::VERSION = '0.41';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -16,13 +16,12 @@ has 'id'          => (is => 'ro', isa => 'Maybe[Str]');
 has 'created'     => (is => 'ro', isa => 'Maybe[Int]');
 has 'used'        => (is => 'ro', isa => 'Maybe[Bool|Object]');
 has 'livemode'    => (is => 'ro', isa => 'Maybe[Bool|Object]');
+has 'type'        => (is => 'ro', isa => 'Maybe[Str]');
+has 'client_ip'   => (is => 'ro', isa => 'Maybe[Str]');
 
 method form_fields {
-    return (
-        (defined $self->card ? $self->card->form_fields : () ),
-        map { $_ => $self->$_ }
-            grep { defined $self->$_ }
-                qw/amount currency/
+    return $self->form_fields_for(
+        qw/amount currency card/
     );
 }
 
@@ -39,7 +38,71 @@ Net::Stripe::Token - represent a Token object from Stripe
 
 =head1 VERSION
 
-version 0.39
+version 0.41
+
+=head1 ATTRIBUTES
+
+=head2 amount
+
+Reader: amount
+
+Type: Maybe[Int]
+
+=head2 boolean_attributes
+
+Reader: boolean_attributes
+
+Type: ArrayRef[Str]
+
+=head2 card
+
+Reader: card
+
+Type: Maybe[Net::Stripe::Card]
+
+This attribute is required.
+
+=head2 client_ip
+
+Reader: client_ip
+
+Type: Maybe[Str]
+
+=head2 created
+
+Reader: created
+
+Type: Maybe[Int]
+
+=head2 currency
+
+Reader: currency
+
+Type: Maybe[Str]
+
+=head2 id
+
+Reader: id
+
+Type: Maybe[Str]
+
+=head2 livemode
+
+Reader: livemode
+
+Type: Maybe[Bool|Object]
+
+=head2 type
+
+Reader: type
+
+Type: Maybe[Str]
+
+=head2 used
+
+Reader: used
+
+Type: Maybe[Bool|Object]
 
 =head1 AUTHORS
 
